@@ -8,10 +8,10 @@ use App::cpm::Logger;
 use Getopt::Long qw(:config no_auto_abbrev no_ignore_case bundling);
 use Pod::Usage ();
 use Cwd 'abs_path';
-use File::Path 'mkpath';
 use Config;
+use version;
 
-our $VERSION = '0.112';
+our $VERSION = '0.113';
 
 sub new {
     my ($class, %option) = @_;
@@ -22,6 +22,7 @@ sub new {
         local_lib => "local",
         cpanmetadb => "http://cpanmetadb.plackperl.org/v1.0/package",
         mirror => "http://www.cpan.org",
+        target_perl => $],
         %option
     }, $class;
 }
@@ -39,12 +40,18 @@ sub parse_options {
         "mirror=s" => \($self->{mirror}),
         "v|verbose" => \($self->{verbose}),
         "w|workers=i" => \($self->{workers}),
+        "target-perl=s" => \my $target_perl,
         "test!" => sub { $self->{notest} = $_[1] ? 0 : 1 },
     or exit 1;
 
     $self->{local_lib} = abs_path $self->{local_lib} unless $self->{global};
     $self->{mirror} =~ s{/$}{};
     $self->{color} = 1 if !defined $self->{color} && -t STDOUT;
+    if ($target_perl) {
+        # 5.8 is interpreted as 5.800, fix it
+        $target_perl = "v$target_perl" if $target_perl =~ /^5\.[1-9]\d+$/;
+        $self->{target_perl} = version->parse($target_perl)->numify;
+    }
 
     $App::cpm::Logger::COLOR = 1 if $self->{color};
     $App::cpm::Logger::VERBOSE = 1 if $self->{verbose};
@@ -119,6 +126,7 @@ sub cmd_install {
     my $master = App::cpm::Master->new(
         core_inc => [$self->_core_inc],
         user_inc => [$self->_user_inc],
+        target_perl => $self->{target_perl},
     );
     my $menlo_base = "$ENV{HOME}/.perl-cpm/work";
     my $menlo_build_log = "$ENV{HOME}/.perl-cpm/build.@{[time]}.log";
@@ -158,18 +166,6 @@ sub cmd_install {
         version => $_->{version} || 0
     ) for @package;
 
-    # prevent local::lib 2.000017+ error
-    # Unable to create /home/skaji/local/lib/perl5: File exists at /home/skaji/env/plenv/versions/c5.8.5/lib/perl5/site_perl/5.8.5/local/lib.pm line 678.
-    # See https://github.com/Perl-Toolchain-Gang/local-lib/commit/2f7bd47d1098d032de6d5f61354e310ad41b1097
-    if (!$self->{global}) {
-        my $v = $Config{version};
-        $v =~ s/^v//;
-        my $lib_v = "$self->{local_lib}/lib/perl5/$v/$Config{archname}";
-        my $lib   = "$self->{local_lib}/lib/perl5/$Config{archname}";
-        my $bin   = "$self->{local_lib}/bin";
-        mkpath $_ for grep !-d, $lib_v, $lib, $bin;
-    }
-
     $master->spawn_worker($cb) for 1 .. $self->{workers};
     MAIN_LOOP:
     while (1) {
